@@ -7,9 +7,9 @@ from .config import cs_axis_up
 
 from System.Windows.Media.Media3D import Point3D
 from System import Array
-from .GeometryViewer.Model.Geometry import Vertex, Edge, EdgeLoop, Face, Volume, Layer, PEdge, GeometricOrientation
-from .GeometryViewer.Model import DerivedColor
-from .ParameterStructure.Instances import SimInstanceType
+from GeometryViewer.Model.Geometry import Vertex, Edge, EdgeLoop, Face, Volume, Layer, PEdge, GeometricOrientation
+from GeometryViewer.Model import DerivedColor
+from ParameterStructure.Instances import SimInstanceType
 # from copy import deepcopy
 # from functools import lru_cache
 # from tqdm import tqdm
@@ -562,44 +562,6 @@ class BaseGeometricFace(BaseGeoBaseClass):
     def orientation(self):
         return self._wrapped_obj.get_Orientation()
 
-    @property
-    def side_1_volume(self):
-        volume = None
-        if not self._wrapped_obj.PFaces:
-            boundary_faces = set(self._wrapped_obj.Boundary.Faces)
-            if boundary_faces.__len__() == 2:
-                try:
-                    boundary_faces.remove(self._wrapped_obj)
-                except:
-                    pass
-
-                if boundary_faces.__len__() == 1:
-                    volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_1_volume
-        else:
-            for p_face in self._wrapped_obj.PFaces:
-                if p_face.Orientation == 1:
-                    volume = self._wrapped_obj.PFaces[0].Volume
-        return volume
-
-    @property
-    def side_2_volume(self):
-        volume = None
-        if not self._wrapped_obj.PFaces:
-            boundary_faces = set(self._wrapped_obj.Boundary.Faces)
-            if boundary_faces.__len__() == 2:
-                try:
-                    boundary_faces.remove(self._wrapped_obj)
-                except:
-                    pass
-
-                if boundary_faces.__len__() == 1:
-                    volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_2_volume
-        else:
-            for p_face in self._wrapped_obj.PFaces:
-                if p_face.Orientation == -1:
-                    volume = self._wrapped_obj.PFaces[1].Volume
-        return volume
-
     @property
     def hull_face(self):
         return None in [self.side_1_volume, self.side_2_volume]
@@ -711,6 +673,51 @@ def create_geo_classes(geo_types):
         def points(self):
             return self.boundary.points
 
+        @property
+        def side_1_volume(self):
+            volume = None
+            if not self._wrapped_obj.PFaces:
+                boundary_faces = set(self._wrapped_obj.Boundary.Faces)
+                if boundary_faces.__len__() == 2:
+                    try:
+                        boundary_faces.remove(self._wrapped_obj)
+                    except:
+                        pass
+
+                    if boundary_faces.__len__() == 1:
+                        volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_1_volume
+            else:
+                for p_face in self._wrapped_obj.PFaces:
+                    if p_face.Orientation == 1:
+                        volume = self._wrapped_obj.PFaces[0].Volume
+
+            if isinstance(volume, Volume):
+                return GeometricVolume.get_obj_by_id(volume.Id)
+            else:
+                return volume
+
+        @property
+        def side_2_volume(self):
+            volume = None
+            if not self._wrapped_obj.PFaces:
+                boundary_faces = set(self._wrapped_obj.Boundary.Faces)
+                if boundary_faces.__len__() == 2:
+                    try:
+                        boundary_faces.remove(self._wrapped_obj)
+                    except:
+                        pass
+
+                    if boundary_faces.__len__() == 1:
+                        volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_2_volume
+            else:
+                for p_face in self._wrapped_obj.PFaces:
+                    if p_face.Orientation == -1:
+                        volume = p_face.Volume
+            if isinstance(volume, Volume):
+                return GeometricVolume.get_obj_by_id(volume.Id)
+            else:
+                return volume
+
     class GeometricVolume(geo_types['volume']):
 
         def __init__(self, *args, **kwargs):
@@ -730,6 +737,15 @@ def create_geo_classes(geo_types):
         def faces(self, value):
             self._faces = value
 
+        @property
+        def adjacent_zones(self):
+
+            adjacent_zones = set()
+            adjacent_zones.update([x.side_1_volume for x in self.faces if x.side_1_volume is not None])
+            adjacent_zones.update([x.side_2_volume for x in self.faces if x.side_2_volume is not None])
+
+            return adjacent_zones
+
     return GeoBaseClass, GeometricLayer, GeometricVertex, GeometricEdge, GeometricEdgeLoop, GeometricFace, GeometricVolume
 
 
